/***************************************************************************
                          ann_loc_io.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_LOC_IO_H
#define __ANN_LOC_IO_H

#include <iostream>

#include <ann_use_size_t.h>
#include <ann_loc.h>

std::ostream &
operator << (std::ostream &os, const ANN::Loc &l);

inline std::ostream &
operator << (std::ostream &os, const ANN::Loc *l)
{
  return os << *l;
}

std::ostream &
operator << (std::ostream &os, const ANN::Size &s);

inline std::ostream &operator << (std::ostream &os, const ANN::Size *s)
{
  return os << *s;
}

#endif /* __ANN_LOC_IO_H */
